EffectCancelled<T> class final

Effect was cancelled before completion.

Inheritance
Annotations

Constructors

EffectCancelled(EffectKey key)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
key EffectKey
Key of the effect that produced this result.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override