EffectResult<T> class sealed

Result of effect execution.

Dispatched as result events after effect completes. Result events are delivered asynchronously (microtask/post-frame) to prevent synchronous reducer recursion.

Implementers

Constructors

EffectResult.cancelled(EffectKey key)
Create cancelled result.
factory
EffectResult.failed(EffectKey key, Object error, StackTrace stack)
Create failed result.
factory
EffectResult.succeeded(EffectKey key, T value)
Create succeeded result.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key EffectKey
Key of the effect that produced this result.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited