HeadlessItemAdapter<T> class final

Annotations

Constructors

HeadlessItemAdapter({required ListboxItemId id(T value), required String primaryText(T value), bool isDisabled(T value)?, String semanticsLabel(T value)?, String searchText(T value)?, HeadlessContent leading(T value)?, HeadlessContent title(T value)?, HeadlessContent subtitle(T value)?, HeadlessContent trailing(T value)?, HeadlessItemFeatures features(T value)?})
const
HeadlessItemAdapter.simple({required ListboxItemId id(T value), required String titleText(T value), String subtitleText(T value)?, String leadingEmoji(T value)?, String semanticsLabel(T value)?, String searchText(T value)?, bool isDisabled(T value)?, HeadlessItemFeatures features(T value)?})
factory

Properties

features HeadlessItemFeatures Function(T value)?
final
hashCode int
The hash code for this object.
no setterinherited
id ListboxItemId Function(T value)
final
isDisabled bool Function(T value)?
final
leading HeadlessContent Function(T value)?
final
primaryText String Function(T value)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchText String Function(T value)?
final
semanticsLabel String Function(T value)?
final
subtitle HeadlessContent Function(T value)?
final
title HeadlessContent Function(T value)?
final
trailing HeadlessContent Function(T value)?
final

Methods

build(T value) HeadlessListItemModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited