HeadlessItemFeatures class final

Annotations

Properties

hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get<T>(HeadlessFeatureKey<T> key) → T?
Gets the value for a typed feature key.
has<T>(HeadlessFeatureKey<T> key) bool
Checks if a feature key is present.
merge(HeadlessItemFeatures other) HeadlessItemFeatures
Merges this features with other, returning a new instance.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

build(void build(HeadlessItemFeaturesBuilder b)) HeadlessItemFeatures

Constants

empty → const HeadlessItemFeatures