HeadlessPressableState class final

Annotations

Constructors

HeadlessPressableState({bool isPressed = false, bool isHovered = false, bool isFocused = false, bool isDisabled = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isDisabled bool
final
isFocused bool
final
isHovered bool
final
isPressed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isPressed, bool? isHovered, bool? isFocused, bool? isDisabled}) HeadlessPressableState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited