ListboxItemId class final

Stable identifier for listbox items.

Components can derive ids from indices or values. The id must be stable for the lifetime of the items list to avoid highlight/selection drift.

Annotations

Constructors

ListboxItemId(String value)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override