ModalFocusPolicy class final

Modal overlay: по умолчанию предполагает trap + restore.

Inheritance

Constructors

ModalFocusPolicy({bool trap = true, bool restoreOnClose = true, FocusNode? initialFocus})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
initialFocus FocusNode?
final
restoreOnClose bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trap bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited