HeadlessFocusHoverController class final
Shared interaction controller for focus+hover (no press/activation).
Intended for components like TextField where the input widget owns focus but visuals need consistent hover/focus state tracking.
- Inheritance
-
- Object
- ChangeNotifier
- HeadlessFocusHoverController
Constructors
- HeadlessFocusHoverController({bool isDisabled = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → HeadlessFocusHoverState
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
handleFocusChange(
bool focused) → void -
handleMouseEnter(
) → void -
handleMouseExit(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setDisabled(
bool isDisabled) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited