SyncEffect<T> class
abstract
Synchronous effect (completes immediately).
Constructors
- SyncEffect()
-
const
Properties
- coalescable → bool
-
Whether this effect can be coalesced with another of same key.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → EffectKey
-
Unique key for this effect (for dedupe/cancel).
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
) → T -
Execute the effect and return result.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited